@@ -84,6 +84,8 @@ from a C type string, or a gtype_name (from g_type_name()).
             return self.ctype
         elif self.gtype_name:
             return self.gtype_name
+        elif self.target_giname:
+            return self.target_giname
         else:
             assert False
 
@@ -95,7 +97,8 @@ in contrast to the other create_type() functions."""
         # First, is it a fundamental?
         fundamental = type_names.get(gtype_name)
         if fundamental is not None:
-            return cls(target_fundamental=fundamental.target_fundamental)
+            return cls(target_fundamental=fundamental.target_fundamental,
+                       ctype=fundamental.ctype)
         if gtype_name == 'GHashTable':
             return Map(TYPE_ANY, TYPE_ANY, gtype_name=gtype_name)
         elif gtype_name in ('GArray', 'GPtrArray', 'GByteArray'):
@@ -415,6 +418,9 @@ but adds it to things like ctypes, symbols, and type_names.
                     continue
                 fn.namespace = self
                 self.symbols[fn.symbol] = fn
+            for member in node.members:
+                member.namespace = self
+                self.symbols[member.symbol] = member
         if hasattr(node, 'ctype'):
             self.ctypes[node.ctype] = node
 
@@ -521,6 +527,17 @@ GIName.  It's possible for nodes to contain or point to other nodes."""
         self.name = name
         self.foreign = False
         self.file_positions = set()
+        self._parent = None
+
+    def _get_parent(self):
+        if self._parent is not None:
+            return self._parent
+        else:
+            return self.namespace
+
+    def _set_parent(self, value):
+        self._parent = value
+    parent = property(_get_parent, _set_parent)
 
     def create_type(self):
         """Create a Type object referencing this node."""
@@ -578,6 +595,14 @@ class Callable(Node):
         self.instance_parameter = None # Parameter
         self.parent = None # A Class or Interface
 
+    # Returns all parameters, including the instance parameter
+    @property
+    def all_parameters(self):
+        if self.instance_parameter is not None:
+            return [self.instance_parameter] + self.parameters
+        else:
+            return self.parameters
+
     def get_parameter_index(self, name):
         for i, parameter in enumerate(self.parameters):
             if parameter.argname == name:
@@ -585,7 +610,7 @@ class Callable(Node):
         raise ValueError("Unknown argument %s" % (name, ))
 
     def get_parameter(self, name):
-        for parameter in self.parameters:
+        for parameter in self.all_parameters:
             if parameter.argname == name:
                 return parameter
         raise ValueError("Unknown argument %s" % (name, ))
@@ -601,6 +626,7 @@ class Function(Callable):
         self.shadowed_by = None # C symbol string
         self.shadows = None # C symbol string
         self.moved_to = None # namespaced function name string
+        self.internal_skipped = False # if True, this func will not be written to GIR
 
     def clone(self):
         clone = copy.copy(self)
@@ -613,7 +639,7 @@ class Function(Callable):
         # Named correctly
         if not (self.name.endswith('_get_type') or
                 self.name.endswith('_get_gtype')):
-                return False
+            return False
 
         # Doesn't have any parameters
         if self.parameters:
@@ -767,6 +793,8 @@ class Enum(Node, Registered):
         self.c_symbol_prefix = c_symbol_prefix
         self.ctype = ctype
         self.members = members
+        for member in members:
+            member.parent = self
         # Associated error domain name
         self.error_domain = None
         self.static_methods = []
@@ -788,6 +816,8 @@ class Bitfield(Node, Registered):
         self.ctype = ctype
         self.c_symbol_prefix = c_symbol_prefix
         self.members = members
+        for member in members:
+            member.parent = self
         self.static_methods = []
 
     def _walk(self, callback, chain):
@@ -803,10 +833,13 @@ class Member(Annotated):
         self.value = value
         self.symbol = symbol
         self.nick = nick
+        self.parent = None
 
     def __cmp__(self, other):
         return cmp(self.name, other.name)
 
+    def __repr__(self):
+        return '%s(%r)' % (self.__class__.__name__, self.name)
 
 
 class Compound(Node, Registered):
@@ -862,6 +895,9 @@ class Field(Annotated):
     def __cmp__(self, other):
         return cmp(self.name, other.name)
 
+    def __repr__(self):
+        return '%s(%r)' % (self.__class__.__name__, self.name)
+
 
 class Record(Compound):
 
@@ -939,7 +975,7 @@ class Signal(Callable):
 
 class Class(Node, Registered):
 
-    def __init__(self, name, parent,
+    def __init__(self, name, parent_type,
                  ctype=None,
                  gtype_name=None,
                  get_type=None,
@@ -949,7 +985,7 @@ class Class(Node, Registered):
         Registered.__init__(self, gtype_name, get_type)
         self.ctype = ctype
         self.c_symbol_prefix = c_symbol_prefix
-        self.parent = parent
+        self.parent_type = parent_type
         self.fundamental = False
         self.unref_func = None
         self.ref_func = None
@@ -988,7 +1024,7 @@ class Class(Node, Registered):
 
 class Interface(Node, Registered):
 
-    def __init__(self, name, parent,
+    def __init__(self, name, parent_type,
                  ctype=None,
                  gtype_name=None,
                  get_type=None,
@@ -997,7 +1033,7 @@ class Interface(Node, Registered):
         Registered.__init__(self, gtype_name, get_type)
         self.ctype = ctype
         self.c_symbol_prefix = c_symbol_prefix
-        self.parent = parent
+        self.parent_type = parent_type
         self.parent_chain = []
         self.methods = []
         self.signals = []
