@@ -21,7 +21,7 @@
 import os
 import optparse
 
-from .mallardwriter import MallardWriter
+from .docwriter import DocWriter
 from .transformer import Transformer
 
 def doc_main(args):
@@ -34,12 +34,13 @@ def doc_main(args):
                       action="store", dest="language",
                       default="Python",
                       help="Output language")
+    parser.add_option("", "--add-include-path",
+                      action="append", dest="include_paths", default=[],
+                      help="include paths for other GIR files")
 
     options, args = parser.parse_args(args)
     if not options.output:
         raise SystemExit("missing output parameter")
-    if not os.path.isdir(options.output):
-        raise SystemExit("wrong output parameter: %s" % (options.output, ))
 
     if len(args) < 2:
         raise SystemExit("Need an input GIR filename")
@@ -50,9 +51,10 @@ def doc_main(args):
         extra_include_dirs = [os.path.join(top_srcdir, 'gir'), top_builddir]
     else:
         extra_include_dirs = []
+    extra_include_dirs.extend(options.include_paths)
     transformer = Transformer.parse_from_gir(args[1], extra_include_dirs)
 
-    writer = MallardWriter(transformer, options.language)
+    writer = DocWriter(transformer, options.language)
     writer.write(options.output)
 
     return 0
