@@ -90,9 +90,6 @@ class GIRParser(object):
             self._pkgconfig_packages = []
         return self._pkgconfig_packages
 
-    def get_doc(self):
-        return parse(self._filename)
-
     # Private
 
     def _find_first_child(self, node, name_or_names):
@@ -218,9 +215,9 @@ class GIRParser(object):
         else:
             parent_type = None
 
-        ctor_args = [node.attrib['name'],
-                     parent_type]
-        ctor_kwargs = {'gtype_name': node.attrib[_glibns('type-name')],
+        ctor_kwargs = {'name': node.attrib['name'],
+                       'parent_type': parent_type,
+                       'gtype_name': node.attrib[_glibns('type-name')],
                        'get_type': node.attrib[_glibns('get-type')],
                        'c_symbol_prefix': node.attrib.get(_cns('symbol-prefix')),
                        'ctype': node.attrib.get(_cns('type'))}
@@ -234,7 +231,7 @@ class GIRParser(object):
         else:
             raise AssertionError(node)
 
-        obj = klass(*ctor_args, **ctor_kwargs)
+        obj = klass(**ctor_kwargs)
         self._parse_generic_attribs(node, obj)
         type_struct = node.attrib.get(_glibns('type-struct'))
         if type_struct:
@@ -289,6 +286,18 @@ class GIRParser(object):
         function = self._parse_function_common(node, ast.Function)
         self._namespace.append(function)
 
+    def _parse_parameter(self, node):
+        typeval = self._parse_type(node)
+        param = ast.Parameter(node.attrib.get('name'),
+                              typeval,
+                              node.attrib.get('direction') or ast.PARAM_DIRECTION_IN,
+                              node.attrib.get('transfer-ownership'),
+                              node.attrib.get('allow-none') == '1',
+                              node.attrib.get('scope'),
+                              node.attrib.get('caller-allocates') == '1')
+        self._parse_generic_attribs(node, param)
+        return param
+
     def _parse_function_common(self, node, klass, parent=None):
         name = node.attrib['name']
         returnnode = node.find(_corens('return-value'))
@@ -326,17 +335,11 @@ class GIRParser(object):
 
         parameters_node = node.find(_corens('parameters'))
         if (parameters_node is not None):
+            paramnode = self._find_first_child(parameters_node, _corens('instance-parameter'))
+            if paramnode:
+                func.instance_parameter = self._parse_parameter(paramnode)
             for paramnode in self._find_children(parameters_node, _corens('parameter')):
-                typeval = self._parse_type(paramnode)
-                param = ast.Parameter(paramnode.attrib.get('name'),
-                                  typeval,
-                                  paramnode.attrib.get('direction') or ast.PARAM_DIRECTION_IN,
-                                  paramnode.attrib.get('transfer-ownership'),
-                                  paramnode.attrib.get('allow-none') == '1',
-                                  paramnode.attrib.get('scope'),
-                                  paramnode.attrib.get('caller-allocates') == '1')
-                self._parse_generic_attribs(paramnode, param)
-                parameters.append(param)
+                parameters.append(self._parse_parameter(paramnode))
             for i, paramnode in enumerate(self._find_children(parameters_node,
                                                               _corens('parameter'))):
                 param = parameters[i]
@@ -584,8 +587,10 @@ class GIRParser(object):
             self._namespace.append(obj)
             return
 
-        for member in self._find_children(node, _corens('member')):
-            members.append(self._parse_member(member))
+        for member_node in self._find_children(node, _corens('member')):
+            member = self._parse_member(member_node)
+            member.parent = obj
+            members.append(member)
         for func_node in self._find_children(node, _corens('function')):
             func = self._parse_function_common(func_node, ast.Function)
             obj.static_methods.append(func)
