@@ -338,10 +338,7 @@ raise ValueError."""
         elif stype == CSYMBOL_TYPE_UNION:
             return self._create_union(symbol)
         elif stype == CSYMBOL_TYPE_CONST:
-            # Don't parse constants which are marked (skip)
-            docblock = self._annotations.get(symbol.ident)
-            if not docblock or not 'skip' in docblock.options:
-                return self._create_const(symbol)
+            return self._create_const(symbol)
         # Ignore variable declarations in the header
         elif stype == CSYMBOL_TYPE_OBJECT:
             pass
@@ -413,7 +410,7 @@ raise ValueError."""
         # Drop functions that start with _ very early on here
         if symbol.ident.startswith('_'):
             return None
-        parameters = list(self._create_parameters(symbol.base_type))
+        parameters = list(self._create_parameters(symbol, symbol.base_type))
         return_ = self._create_return(symbol.base_type.base_type)
         try:
             name = self._strip_symbol(symbol)
@@ -481,11 +478,11 @@ raise ValueError."""
 
         return value
 
-    def _create_parameters(self, base_type):
+    def _create_parameters(self, symbol, base_type):
         # warn if we see annotations for unknown parameters
         param_names = set(child.ident for child in base_type.child_list)
         for child in base_type.child_list:
-            yield self._create_parameter(child)
+            yield self._create_parameter(symbol, child)
 
     def _synthesize_union_type(self, symbol, parent_symbol):
         # Synthesize a named union so that it can be referenced.
@@ -698,11 +695,15 @@ raise ValueError."""
             return container
         return ast.Type(ctype=ctype, is_const=is_const, complete_ctype=complete_ctype)
 
-    def _create_parameter(self, symbol):
+    def _create_parameter(self, parent_symbol, symbol):
         if symbol.type == CSYMBOL_TYPE_ELLIPSIS:
             ptype = ast.Varargs()
         else:
             ptype = self._create_type_from_base(symbol.base_type, is_parameter=True)
+
+        if symbol.ident is None and symbol.base_type and symbol.base_type.type != CTYPE_VOID:
+            message.warn_symbol(parent_symbol, "missing parameter name; undocumentable")
+
         return ast.Parameter(symbol.ident, ptype)
 
     def _create_return(self, source_type):
@@ -838,7 +839,7 @@ raise ValueError."""
         return self._create_compound(ast.Union, symbol, anonymous)
 
     def _create_callback(self, symbol, member=False):
-        parameters = list(self._create_parameters(symbol.base_type.base_type))
+        parameters = list(self._create_parameters(symbol, symbol.base_type.base_type))
         retval = self._create_return(symbol.base_type.base_type.base_type)
 
         # Mark the 'user_data' arguments
@@ -876,9 +877,12 @@ Note that type resolution may not succeed."""
         if '.' in typestr:
             container = self._create_bare_container_type(typestr)
             if container:
-                return container
-            return self._namespace.type_from_name(typestr)
-        typeval = self.create_type_from_ctype_string(typestr)
+                typeval = container
+            else:
+                typeval = self._namespace.type_from_name(typestr)
+        else:
+            typeval = self.create_type_from_ctype_string(typestr)
+
         self.resolve_type(typeval)
         if typeval.resolved:
             # Explicitly clear out the c_type; there isn't one in this case.
@@ -923,7 +927,7 @@ Note that type resolution may not succeed."""
                 return True
         return False
 
-    def resolve_type(self, typeval):
+    def _resolve_type_internal(self, typeval):
         if isinstance(typeval, (ast.Array, ast.List)):
             return self.resolve_type(typeval.element_type)
         elif isinstance(typeval, ast.Map):
@@ -937,6 +941,25 @@ Note that type resolution may not succeed."""
         elif typeval.gtype_name:
             return self._resolve_type_from_gtype_name(typeval)
 
+    def resolve_type(self, typeval):
+        if not self._resolve_type_internal(typeval):
+            return False
+
+        if typeval.target_fundamental or typeval.target_foreign:
+            return True
+
+        assert typeval.target_giname is not None
+
+        try:
+            type_ = self.lookup_giname(typeval.target_giname)
+        except KeyError:
+            type_ = None
+
+        if type_ is None:
+            typeval.target_giname = None
+
+        return typeval.resolved
+
     def _typepair_to_str(self, item):
         nsname, item = item
         if nsname is None:
