@@ -3,7 +3,6 @@
 #include <stdlib.h>
 #include <glib-object.h>
 #include <gobject/gvaluecollector.h>
-#include <cairo-gobject.h>
 
 #include "regress.h"
 
@@ -285,6 +284,7 @@ regress_test_value_return(int i)
 /************************************************************************/
 /* foreign structs */
 
+#ifndef _GI_DISABLE_CAIRO
 /**
  * regress_test_cairo_context_full_return:
  *
@@ -365,6 +365,7 @@ regress_test_cairo_surface_full_out (cairo_surface_t **surface)
 {
   *surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, 10, 10);
 }
+#endif
 
 /**
  * regress_test_gvariant_i:
@@ -907,7 +908,7 @@ regress_test_array_int_null_out (int **arr, int *len)
 /* GList */
 
 static /*const*/ GList *
-regress_test_sequence_list()
+regress_test_sequence_list (void)
 {
     static GList *list = NULL;
     if (!list) {
@@ -1028,7 +1029,7 @@ regress_test_glist_null_out (GSList **out_list)
 /* GSList */
 
 static /*const*/ GSList *
-regress_test_sequence_slist()
+regress_test_sequence_slist (void)
 {
     static GSList *list = NULL;
     if (!list) {
@@ -1152,7 +1153,7 @@ static char *table_data[3][2] = {
 };
 
 static GHashTable *
-regress_test_table_ghash_new_container()
+regress_test_table_ghash_new_container (void)
 {
   GHashTable *hash;
   int i;
@@ -1163,7 +1164,7 @@ regress_test_table_ghash_new_container()
 }
 
 static GHashTable *
-regress_test_table_ghash_new_full()
+regress_test_table_ghash_new_full (void)
 {
   GHashTable *hash;
   int i;
@@ -1176,7 +1177,7 @@ regress_test_table_ghash_new_full()
 }
 
 static /*const*/ GHashTable *
-regress_test_table_ghash_const()
+regress_test_table_ghash_const (void)
 {
   static GHashTable *hash = NULL;
   if (!hash) {
@@ -2181,6 +2182,7 @@ enum {
   REGRESS_TEST_OBJ_SIGNAL_ALL,
   REGRESS_TEST_OBJ_SIGNAL_SIG_WITH_INT64_PROP,
   REGRESS_TEST_OBJ_SIGNAL_SIG_WITH_UINT64_PROP,
+  REGRESS_TEST_OBJ_SIGNAL_SIG_WITH_INTARRAY_RET,
   N_REGRESS_TEST_OBJ_SIGNALS
 };
 
@@ -2297,6 +2299,7 @@ regress_test_obj_class_init (RegressTestObjClass *klass)
 		  1,
 		  G_TYPE_OBJECT);
 
+#ifndef _GI_DISABLE_CAIRO
    /**
    * RegressTestObj::sig-with-foreign-struct:
    * @self: an object
@@ -2313,6 +2316,7 @@ regress_test_obj_class_init (RegressTestObjClass *klass)
 		  G_TYPE_NONE,
 		  1,
 		  CAIRO_GOBJECT_TYPE_CONTEXT);
+#endif
 
   regress_test_obj_signals[REGRESS_TEST_OBJ_SIGNAL_FIRST] =
     g_signal_new ("first",
@@ -2387,6 +2391,25 @@ regress_test_obj_class_init (RegressTestObjClass *klass)
 		  1,
 		  G_TYPE_UINT64);
 
+  /**
+   * RegressTestObj::sig-with-intarray-ret:
+   * @self: an object
+   * @i: an integer
+   *
+   * Returns: (array zero-terminated=1) (element-type gint) (transfer full):
+   */
+  regress_test_obj_signals[REGRESS_TEST_OBJ_SIGNAL_SIG_WITH_INTARRAY_RET] =
+    g_signal_new ("sig-with-intarray-ret",
+		  G_TYPE_FROM_CLASS (gobject_class),
+		  G_SIGNAL_RUN_LAST,
+		  0,
+		  NULL,
+		  NULL,
+		  g_cclosure_marshal_VOID__BOXED,
+		  G_TYPE_ARRAY,
+		  1,
+		  G_TYPE_INT);
+
   gobject_class->set_property = regress_test_obj_set_property;
   gobject_class->get_property = regress_test_obj_get_property;
   gobject_class->dispose = regress_test_obj_dispose;
@@ -2600,6 +2623,7 @@ regress_test_obj_emit_sig_with_obj (RegressTestObj *obj)
     g_object_unref (obj_param);
 }
 
+#ifndef _GI_DISABLE_CAIRO
 void
 regress_test_obj_emit_sig_with_foreign_struct (RegressTestObj *obj)
 {
@@ -2607,6 +2631,7 @@ regress_test_obj_emit_sig_with_foreign_struct (RegressTestObj *obj)
   g_signal_emit_by_name (obj, "sig-with-foreign-struct", cr);
   cairo_destroy (cr);
 }
+#endif
 
 void
 regress_test_obj_emit_sig_with_int64 (RegressTestObj *obj)
